@@ -229,7 +229,7 @@ class ShellTest(utils.TestCase):
         #                   {'rebuild': {'imageRef': 1}})
         self.assert_called('GET', '/images/2')
 
-        self.run_command('rebuild sample-server 1 --rebuild-password asdf')
+        self.run_command('rebuild sample-server 1 --rebuild_password asdf')
         # XXX need a way to test multiple calls
         #self.assert_called('POST', '/servers/1234/action',
         #                   {'rebuild': {'imageRef': 1, 'adminPass': 'asdf'}})
@@ -320,7 +320,7 @@ class ShellTest(utils.TestCase):
 
     def test_dns_create_private_domain(self):
         self.run_command('dns-create-private-domain testdomain '
-                         '--availability-zone av_zone')
+                         '--availability_zone av_zone')
         self.assert_called('PUT', '/os-floating-ip-dns/testdomain')
 
     def test_dns_delete(self):
@@ -359,8 +359,7 @@ class ShellTest(utils.TestCase):
 
     def test_flavor_create(self):
         self.run_command("flavor-create flavorcreate "
-                         "1234 512 10 1 --swap 1024 --ephemeral 10 "
-                         "--is-public true")
+                         "1234 512 10 1 --swap 1024 --ephemeral 10")
 
         body = {
             "flavor": {
@@ -372,7 +371,6 @@ class ShellTest(utils.TestCase):
                 "id": 1234,
                 "swap": 1024,
                 "rxtx_factor": 1,
-                "os-flavor-access:is_public": True,
             }
         }
 
@@ -430,13 +428,13 @@ class ShellTest(utils.TestCase):
                                             'block_migration': False,
                                             'disk_over_commit': False}})
         self.run_command('live-migration sample-server hostname \
-                         --block-migrate')
+                         --block_migrate')
         self.assert_called('POST', '/servers/1234/action',
                            {'os-migrateLive': {'host': 'hostname',
                                             'block_migration': True,
                                             'disk_over_commit': False}})
         self.run_command('live-migration sample-server hostname \
-                         --block-migrate --disk-over-commit')
+                         --block_migrate --disk_over_commit')
         self.assert_called('POST', '/servers/1234/action',
                            {'os-migrateLive': {'host': 'hostname',
                                             'block_migration': True,
